// ---------------------------------------------------------------------------
// weaponHUD.cs -- Version 1.3 -- December 9, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Show the name of your current weapon on the screen (helpful when playing mods)
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\weaponHUD.cs", "1.3", "Lorne Laliberte", "Dec 9, 2000");

include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\item_events.cs");
include("writer\\save.cs");
include("writer\\scroller.cs");
include("writer\\station_events.cs");
include("writer\\weapon_switch.cs");
include("writer\\whud.cs");
include("writer\\you_died.cs");
include("writer\\you_respawned.cs");
include("writer\\you_spawned.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_weaponHUD.cs file

    // Screen coordinates for weaponHUD
    $weaponHUD::X = "100%";
    $weaponHUD::Y = "100%";

    // Default colour to use (0 = brown, 1 = light tan, 2 = white)
    $weaponHUD::Colour = "1";

    // Make the weaponHUD background transparent
    $weaponHUD::Transparent = "false";

    // Enable weaponHUD by default
    $weaponHUD::visible = "true";

    // Width of the hud in pixels -- make sure it's wide enough for the text
    $weaponHUD::width = "150";

    // Toggle weaponHUD on/off
    //bind(keyboard0, make, alt, "whatever", TO, "weaponHUD::toggle();");
    //bind(keyboard0, break, alt, "whatever", TO, "", weaponHUD::toggle_break);

    // Cycle through available colours
    //bind(keyboard0, make, alt, "whatever", TO, "weaponHUD::nextColour();");
    //bind(keyboard0, break, alt, "whatever", TO, "", weaponHUD::nextColour_break);

// ---------------------------------------------------------------------------

WriterPrefs::load("weaponHUD");

$weaponHUD::height=18;

function weaponHUD::toggle()
{
    if($weaponHUD::visible = !$weaponHUD::visible)
        wHUD::show(weapon_HUD);
    else
        wHUD::hide(weapon_HUD);
}

function weaponHUD::setup()
{
    if($weaponHUD::transparent)
    {
        $weaponHUD::ColourText[0] = "<f0>";
        $weaponHUD::ColourText[1] = "<f1>";
        $weaponHUD::ColourText[2] = "<f2>";
    }
    else
    {
        $weaponHUD::ColourText[0] = "<f0><jc>";
        $weaponHUD::ColourText[1] = "<f1><jc>";
        $weaponHUD::ColourText[2] = "<f2><jc>";
    }
}

function weaponHUD::nextColour()
{
    $weaponHUD::Colour++;
    if($weaponHUD::Colour > 2)
        $weaponHUD::Colour = 0;

    wHUD::update(weapon_HUD, $weaponHUD::currentText);
}


function weaponHUD::onYouDied()
{
    if(wHUD::exists(weapon_HUD))
        Scroller::start(weapon_HUD, "                  weaponHUD 1.1 by Lorne Laliberte (Writer), hope you enjoy this nifty little HUD. :)        ,+'`'+._,+'`'+._,+'`'+._,+'`'+._,+'`'+.", 18, 0.1, $weaponHUD::ColourText[$weaponHUD::Colour]);

    return;
}


function weaponHUD::onYouRespawned()
{
    scroller::stop(weapon_HUD);

    wHUD::update(weapon_HUD, "");

    schedule::add("wHUD::update(weapon_HUD, $weaponHUD::ColourText[$weaponHUD::Colour] @ $Inv::Name[getmounteditem(0)]);", 1);
    return;
}


function weaponHUD::onWeaponSwitch(%weapon, %fromWeapon)
{
    $weaponHUD::currentText = "";

    if(%weapon != -1)
        $weaponHUD::currentText = $weaponHUD::ColourText[$weaponHUD::Colour] @ $Inv::Name[%weapon];

    wHUD::update(weapon_HUD, $weaponHUD::currentText);

    if($weaponHUD::visible)
        wHUD::show(weapon_HUD);

    return;
}

function weaponHUD::show()
{
    if($weaponHUD::visible)
        wHUD::show(weapon_HUD);

    return;
}

function weaponHUD::hide()
{
    wHUD::hide(weapon_HUD);
    return;
}


function weaponHUD::onYouSpawned()
{
    if(!wHUD::exists(weapon_HUD))
    {
        weaponHUD::setup();
        $weaponHUD::currentText = "";

        %weapon = getmounteditem(0);

        if(%weapon != -1)
            $weaponHUD::currentText = $weaponHUD::ColourText[$weaponHUD::Colour] @ $Inv::Name[%weapon];

        // Build weaponHUD on first weapon switch, after playGui exists
        wHUD::makeMoveable(1, 1, 0, weapon_HUD, $weaponHUD::x, $weaponHUD::y, $weaponHUD::width, $weaponHUD::height, $weaponHUD::transparent, $weaponHUD::visible, $weaponHUD::currentText);
    }
    else
    {
        if($weaponHUD::visible)
            wHUD::show(weapon_HUD);
    }
    return;
}


function weaponHUD::relocate()
{
    wHUD::makeMoveable(1, 1, 0, weapon_HUD, $weaponHUD::x, $weaponHUD::y, $weaponHUD::width, $weaponHUD::height, $weaponHUD::transparent, $weaponHUD::visible, $weaponHUD::currentText);
    return;
}


function onHudMove_weapon_HUD(%x, %y, %width, %height)
{
    $weaponHUD::x = %x;
    $weaponHUD::y = %y;
    $weaponHUD::width = %width;
    wHUD::make(weapon_HUD, $weaponHUD::x, $weaponHUD::y, $weaponHUD::width, $weaponHUD::height, $weaponHUD::transparent, 1, $weaponHUD::currentText);
    return;
}


function weaponHUD::onChangeMission()
{
    $weaponHUD::currentText = "";

    wHUD::update(weapon_HUD, "");
    return;
}


function weaponHUD::save()
{
    AddExportText("    // Screen coordinates for weaponHUD");
    ExportSetting("    $weaponHUD::X", "100%");
    ExportSetting("    $weaponHUD::Y", "100%");
    AddExportText("");
    AddExportText("    // Default colour to use (0 = brown, 1 = light tan, 2 = white)");
    ExportSetting("    $weaponHUD::Colour", 1);
    AddExportText("");
    AddExportText("    // Make the weaponHUD background transparent");
    ExportSetting("    $weaponHUD::Transparent", false);
    AddExportText("");
    AddExportText("    // Enable weaponHUD by default");
    ExportSetting("    $weaponHUD::visible", true);
    AddExportText("");
    AddExportText("    // Width of the hud in pixels -- make sure it's wide enough for the text");
    ExportSetting("    $weaponHUD::width", 150);
    AddExportText("");
    AddExportText("    // Toggle weaponHUD on/off");

    ExportBind("weaponHUD::toggle();", "//bind(keyboard0, make, alt, \"whatever\", TO, \"weaponHUD::toggle();\");");
    ExportBind("weaponHUD::toggle_break", "//bind(keyboard0, break, alt, \"whatever\", TO, \"\", weaponHUD::toggle_break);");

    AddExportText("");
    AddExportText("    // Cycle through available colours");

    ExportBind("weaponHUD::nextColour();", "//bind(keyboard0, make, alt, \"whatever\", TO, \"weaponHUD::nextColour();\");");
    ExportBind("weaponHUD::nextColour_break", "//bind(keyboard0, break, alt, \"whatever\", TO, \"\", weaponHUD::nextColour_break);");
}

WriterPrefs::save("weaponHUD");

function weaponHUD::init()
{
    needs("writer\\weaponHUD.cs", "writer\\event.cs 2.7",
                                  "writer\\inventory.cs 3.3",
                                  "writer\\item_events.cs 2.12",
                                  "writer\\save.cs 2.3",
                                  "writer\\scroller.cs 1.1",
                                  "writer\\station_events.cs 4.8",
                                  "writer\\weapon_switch.cs 2.5",
                                  "writer\\whud.cs 1.2",
                                  "writer\\you_died.cs 1.6",
                                  "writer\\you_respawned.cs 1.2",
                                  "writer\\you_spawned.cs 1.1");

    Event::Attach(eventChangeMission, "weaponHUD::onChangeMission();");
    Event::Attach(eventEnterCommandStation, "weaponHUD::hide();");
    Event::Attach(eventExitCommandStation, "weaponHUD::hide();");
    Event::Attach(eventPilotModeOn, "weaponHUD::hide();");
    Event::Attach(eventPilotModeOff, "weaponHUD::show();");
    Event::Attach(eventScreenModeChanged, "weaponHUD::relocate();");
    Event::Attach(eventScreenSizeChanged, "weaponHUD::relocate();");
    Event::Attach(eventWeaponSwitch, weaponHUD::onWeaponSwitch);
    Event::Attach(eventYouDied, "weaponHUD::onYouDied();");
    Event::Attach(eventYouRespawned, "weaponHUD::onYouRespawned();");
    Event::Attach(eventYouSpawned, "weaponHUD::onYouSpawned();");
    Event::Attach(wHudMove_weapon_HUD, onHudMove_weapon_HUD);
    Event::Attach(wHudSave_weaponHUD, "WriterPrefs::save(\"weaponHUD\");");
}
Event::Attach(writerInit, "weaponHUD::init();");

if(!$UsingWriterLoader) weaponHUD::init();
